org.openqa.selenium.server.commands (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

## Package org.openqa.selenium.server.commands

Class Summary
AddCustomRequestHeaderCommand |
CaptureEntirePageScreenshotToStringCommand | Capture a screenshot of the in-browser canvas.
CaptureNetworkTrafficCommand |
CaptureNetworkTrafficCommand.Entry |
CaptureNetworkTrafficCommand.Header |
CaptureScreenshotCommand | Captures a full screen shot of the current screen using the java.awt.Robot class.
CaptureScreenshotToStringCommand | Captures a full screen shot of the current screen using the java.awt.Robot class.
Command | Selenium Command
RetrieveLastRemoteControlLogsCommand | Retrieve the last N remote control logs.
SeleniumCoreCommand | Command delegated "as-is" to Selenium Core.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.